poetry_core: Poetry PEP 517 Build Backend
=========================================

Description
-----------

Poetry PEP 517 Build Backend

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/poetry-core/

